from .client import NacosClient, NacosException, DEFAULTS, DEFAULT_GROUP_NAME
from . import configer
__version__ = client.VERSION

__all__ = ["NacosClient", "NacosException", "DEFAULTS", DEFAULT_GROUP_NAME, 'configer']



import nacos
from django.conf import settings


def client(namespace: str = None):
    """client 获取nacos客户端
    需配置settings.NACOS = dict(servers='a,b', namespace='namespace id', ak='username', sk='password')

    :param namespace: 命名空间id, defaults to None
    :type namespace: str, optional
    """

    servers = settings.NACOS["servers"]
    namespace = namespace or settings.NACOS["namespace"]
    ak = settings.NACOS["ak"]
    sk = settings.NACOS["sk"]
    return nacos.NacosClient(servers, namespace=namespace, ak=ak, sk=sk)



from setuptools import setup, find_packages
import django_nacos as nacos


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="django-nacos",
    version=nacos.__version__,
    packages=find_packages(exclude=["test"]),
    url="https://github.com/nacos-group/nacos-sdk-python",
    license="Apache License 2.0",
    author="nacos",
    author_email="755063194@qq.com",
    description="Python client for Nacos.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[],
)
